summaryrefslogtreecommitdiff
path: root/src/testing
diff options
context:
space:
mode:
authorJonathan Buchanan <jonathan.russ.buchanan@gmail.com>2020-06-24 17:38:09 -0400
committerJonathan Buchanan <jonathan.russ.buchanan@gmail.com>2020-06-24 17:38:09 -0400
commit0fbdd6c6cda1c7e0ad0b4ffc3f22bac3e1176c1d (patch)
tree8935dc12924a27e8c1112314b88fa895e1bf1240 /src/testing
parentebfa7888c0cbb461cf70a8d809b1d183011713ce (diff)
downloadmerchant-0fbdd6c6cda1c7e0ad0b4ffc3f22bac3e1176c1d.tar.gz
merchant-0fbdd6c6cda1c7e0ad0b4ffc3f22bac3e1176c1d.tar.bz2
merchant-0fbdd6c6cda1c7e0ad0b4ffc3f22bac3e1176c1d.zip
got refunds working and tested
Diffstat (limited to 'src/testing')
-rw-r--r--src/testing/test_merchant_api.c40
-rw-r--r--src/testing/testing_api_cmd_merchant_get_order.c25
-rw-r--r--src/testing/testing_api_cmd_wallet_get_order.c34
3 files changed, 90 insertions, 9 deletions
diff --git a/src/testing/test_merchant_api.c b/src/testing/test_merchant_api.c
index 1752ab16..0856757b 100644
--- a/src/testing/test_merchant_api.c
+++ b/src/testing/test_merchant_api.c
@@ -291,10 +291,14 @@ run (void *cls,
TALER_TESTING_cmd_wallet_get_order ("get-order-wallet-1",
merchant_url,
"create-proposal-1",
+ false,
+ false,
MHD_HTTP_OK),
TALER_TESTING_cmd_merchant_get_order ("get-order-merchant-1",
merchant_url,
"create-proposal-1",
+ false,
+ false,
MHD_HTTP_OK),
#if 0
TALER_TESTING_cmd_check_payment ("check-payment-1",
@@ -328,6 +332,18 @@ run (void *cls,
"withdraw-coin-1",
"EUR:5",
"EUR:4.99"),
+ TALER_TESTING_cmd_wallet_get_order ("get-order-wallet-1-2",
+ merchant_url,
+ "create-proposal-1",
+ true,
+ false,
+ MHD_HTTP_OK),
+ TALER_TESTING_cmd_merchant_get_order ("get-order-merchant-1-2",
+ merchant_url,
+ "create-proposal-1",
+ true,
+ false,
+ MHD_HTTP_OK),
#if 0
TALER_TESTING_cmd_poll_payment_conclude ("poll-payment-conclude-2",
MHD_HTTP_OK,
@@ -546,6 +562,13 @@ run (void *cls,
"1r", /* order ID */
"EUR:0.1",
MHD_HTTP_OK),
+ /*
+ TALER_TESTING_cmd_wallet_get_order ("get-order-wallet-1r",
+ merchant_url,
+ "create-proposal-1r",
+ true,
+ true,
+ MHD_HTTP_OK),*/
#if 0
TALER_TESTING_cmd_poll_payment_conclude ("poll-payment-refund-conclude-1",
MHD_HTTP_OK,
@@ -588,12 +611,13 @@ run (void *cls,
"EUR:0.1",
MHD_HTTP_CONFLICT),
/* Try to increase a non existent proposal. */
- TALER_TESTING_cmd_merchant_order_refund ("refund-increase-unpaid-proposal",
- merchant_url,
- "refund test",
- "non-existent-id",
- "EUR:0.1",
- MHD_HTTP_NOT_FOUND),
+ TALER_TESTING_cmd_merchant_order_refund (
+ "refund-increase-nonexistent-proposal",
+ merchant_url,
+ "refund test",
+ "non-existent-id",
+ "EUR:0.1",
+ MHD_HTTP_NOT_FOUND),
/*
The following block will (1) create a new
reserve, then (2) a proposal, then (3) pay for
@@ -638,7 +662,7 @@ run (void *cls,
TALER_TESTING_cmd_check_bank_transfer (
"check_bank_transfer-paid-unincreased-refund",
EXCHANGE_URL,
- "EUR:9.88", /* '4.98 from above', plus 4.99 from 'pay-for-refund-1r'
+ "EUR:9.97", /* '4.98 from above', plus 4.99 from 'pay-for-refund-1r'
and MINUS 0.1 PLUS 0.01 (deposit fee) from 'refund-increase-1r' */
exchange_payto,
merchant_payto),
@@ -1126,8 +1150,10 @@ run (void *cls,
0,
10,
10),
+#endif
TALER_TESTING_cmd_batch ("refund",
refund),
+#if 0
// #endif
TALER_TESTING_cmd_batch ("tip",
tip),
diff --git a/src/testing/testing_api_cmd_merchant_get_order.c b/src/testing/testing_api_cmd_merchant_get_order.c
index 985e9116..739e4efa 100644
--- a/src/testing/testing_api_cmd_merchant_get_order.c
+++ b/src/testing/testing_api_cmd_merchant_get_order.c
@@ -57,6 +57,16 @@ struct MerchantGetOrderState
* Reference to a command that created an order.
*/
const char *order_reference;
+
+ /**
+ * Whether the order was paid or not.
+ */
+ bool paid;
+
+ /**
+ * Whether the order was refunded or not.
+ */
+ bool refunded;
};
@@ -97,6 +107,13 @@ merchant_get_order_cb (
case MHD_HTTP_OK:
// FIXME: use gts->tip_reference here to
// check if the data returned matches that from the POST / PATCH
+ if (gos->paid != osr->paid)
+ {
+ GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+ "Order paid does not match\n");
+ TALER_TESTING_interpreter_fail (gos->is);
+ return;
+ }
break;
default:
GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
@@ -174,18 +191,22 @@ merchant_get_order_cleanup (void *cls,
/**
- * Define a GET /private/tips/$TIP_ID CMD.
+ * Define a GET /private/orders/$ORDER_ID CMD.
*
* @param label the command label
* @param merchant_url base URL of the merchant which will
* serve the request.
* @param order_reference reference to a command that created an order.
+ * @param paid whether the order has been paid for or not.
+ * @param refunded whether the order has been refunded.
* @param http_status expected HTTP response code for the request.
*/
struct TALER_TESTING_Command
TALER_TESTING_cmd_merchant_get_order (const char *label,
const char *merchant_url,
const char *order_reference,
+ bool paid,
+ bool refunded,
unsigned int http_status)
{
struct MerchantGetOrderState *gos;
@@ -193,6 +214,8 @@ TALER_TESTING_cmd_merchant_get_order (const char *label,
gos = GNUNET_new (struct MerchantGetOrderState);
gos->merchant_url = merchant_url;
gos->order_reference = order_reference;
+ gos->paid = paid;
+ gos->refunded = refunded;
gos->http_status = http_status;
{
struct TALER_TESTING_Command cmd = {
diff --git a/src/testing/testing_api_cmd_wallet_get_order.c b/src/testing/testing_api_cmd_wallet_get_order.c
index 1dce69c9..7cc9c352 100644
--- a/src/testing/testing_api_cmd_wallet_get_order.c
+++ b/src/testing/testing_api_cmd_wallet_get_order.c
@@ -57,6 +57,16 @@ struct WalletGetOrderState
* Reference to a command that created an order.
*/
const char *order_reference;
+
+ /**
+ * Whether the order was paid or not.
+ */
+ bool paid;
+
+ /**
+ * Whether the order was refunded or not.
+ */
+ bool refunded;
};
@@ -95,6 +105,8 @@ wallet_get_order_cb (
{
/* FIXME, deeper checks should be implemented here. */
struct WalletGetOrderState *gos = cls;
+ bool paid_b = (paid == GNUNET_YES);
+ bool refunded_b = (refunded == GNUNET_YES);
gos->ogh = NULL;
if (gos->http_status != hr->http_status)
@@ -110,8 +122,22 @@ wallet_get_order_cb (
switch (hr->http_status)
{
case MHD_HTTP_OK:
// FIXME: use gts->tip_reference here to
// check if the data returned matches that from the POST / PATCH
+ if (gos->paid != paid_b)
+ {
+ GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+ "Order paid does not match\n");
+ TALER_TESTING_interpreter_fail (gos->is);
+ return;
+ }
+ if (gos->refunded != refunded_b)
+ {
+ GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+ "Order refunded does not match\n");
+ TALER_TESTING_interpreter_fail (gos->is);
+ return;
+ }
break;
default:
GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
@@ -196,12 +222,16 @@ wallet_get_order_cleanup (void *cls,
* @param merchant_url base URL of the merchant which will
* serve the request.
* @param order_reference reference to a command that created an order.
+ * @param paid whether the order has been paid for or not.
+ * @param refunded whether the order has been refunded.
* @param http_status expected HTTP response code for the request.
*/
struct TALER_TESTING_Command
TALER_TESTING_cmd_wallet_get_order (const char *label,
const char *merchant_url,
const char *order_reference,
+ bool paid,
+ bool refunded,
unsigned int http_status)
{
struct WalletGetOrderState *gos;
@@ -210,6 +240,8 @@ TALER_TESTING_cmd_wallet_get_order (const char *label,
gos->merchant_url = merchant_url;
gos->order_reference = order_reference;
gos->http_status = http_status;
+ gos->paid = paid;
+ gos->refunded = refunded;
{
struct TALER_TESTING_Command cmd = {
.cls = gos,
@@ -110,8 +122,22 @@ wallet_get_order_cb (
{
case MHD_HTTP_OK:
- // FIXME: use gts->tip_reference here to
+ // FIXME: use gos->order_reference here to
// check if the data returned matches that from the POST / PATCH